@@ -34,11 +34,14 @@ class SolarUtil:
         "9-10": "教师节",
         "10-1": "国庆节",
         "12-24": "平安夜",
-        "12-25": "圣诞节"
+        "12-25": "圣诞节",
+        "10-31": "万圣节前夜",
+        "11-1": "万圣节"
     }
 
     # 几月第几个星期几对应的节日
     WEEK_FESTIVAL = {
+        "3-0-1": "全国中小学生安全教育日",
         "5-2-0": "母亲节",
         "6-3-0": "父亲节",
         "11-4-4": "感恩节"
